@@ -46,12 +46,11 @@
  * functions.
  *
  * Since module unload order is based on reference counting, any module that
- * uses the API defined in this file must call stasis_app_ref() when loaded,
- * and stasis_app_unref() when unloaded.
+ * uses the API defined in this file must list "res_stasis" in the requires
+ * field.
  */
 
 #include "asterisk/channel.h"
-#include "asterisk/json.h"
 
 /*! @{ */
 
@@ -72,10 +71,30 @@ typedef void (*stasis_app_cb)(void *data, const char *app_name,
  * \brief Gets the names of all registered Stasis applications.
  *
  * \return \c ast_str_container of container names.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ao2_container *stasis_app_get_all(void);
 
+/*!
+ * \brief Retrieve a handle to a Stasis application by its name
+ *
+ * \param name The name of the registered Stasis application
+ *
+ * \return \c stasis_app on success.
+ * \retval NULL on error.
+ */
+struct stasis_app *stasis_app_get_by_name(const char *name);
+
+/*!
+ * \brief Check if a Stasis application is registered.
+ *
+ * \param name The name of the registered Stasis application
+ *
+ * \return 1 if the application is registered.
+ * \return 0 if the application is not registered.
+ */
+int stasis_app_is_registered(const char *name);
+
 /*!
  * \brief Register a new Stasis application.
  *
@@ -107,7 +126,7 @@ int stasis_app_register(const char *app_name, stasis_app_cb handler, void *data)
 int stasis_app_register_all(const char *app_name, stasis_app_cb handler, void *data);
 
 /*!
- * \brief Unregister a Stasis application.
+ * \brief Unregister a Stasis application and unsubscribe from all event sources.
  * \param app_name Name of the application to unregister.
  */
 void stasis_app_unregister(const char *app_name);
@@ -138,13 +157,24 @@ struct stasis_app;
  */
 const char *stasis_app_name(const struct stasis_app *app);
 
+/*!
+ * \brief Return the JSON representation of a Stasis application.
+ * \since 16.3.0
+ *
+ * \param app The application.
+ *
+ * \return JSON representation of app with given name.
+ * \retval NULL on error.
+ */
+struct ast_json *stasis_app_object_to_json(struct stasis_app *app);
+
 /*!
  * \brief Return the JSON representation of a Stasis application.
  *
  * \param app_name Name of the application.
  *
  * \return JSON representation of app with given name.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *stasis_app_to_json(const char *app_name);
 
@@ -219,18 +249,6 @@ void stasis_app_register_event_source(struct stasis_app_event_source *obj);
  */
 void stasis_app_register_event_sources(void);
 
-/*!
- * \brief Checks to see if the given object is a core event source
- *
- * \note core event sources are currently only endpoint, bridge, and channel.
- *
- * \param obj event source object to check
- *
- * \return non-zero if core event source, otherwise 0 (false)
-
- */
-int stasis_app_is_core_event_source(struct stasis_app_event_source *obj);
-
 /*!
  * \brief Unregister an application event source.
  *
@@ -439,34 +457,39 @@ void stasis_app_control_execute_until_exhausted(
 int stasis_app_control_is_done(
 	struct stasis_app_control *control);
 
+/*!
+ * \brief Set the failed flag on a control structure
+ *
+ * \param control Control object to be updated
+ */
+void stasis_app_control_mark_failed(struct stasis_app_control *control);
+
+/*!
+ * \brief Check if a control object is marked as "failed"
+ *
+ * \param control Control object to check
+ */
+int stasis_app_control_is_failed(const struct stasis_app_control *control);
+
+/*!
+ * \brief Flush the control command queue.
+ * \since 13.9.0
+ *
+ * \param control Control object to flush command queue.
+ */
+void stasis_app_control_flush_queue(struct stasis_app_control *control);
+
 /*!
  * \brief Returns the uniqueid of the channel associated with this control
  *
  * \param control Control object.
  *
  * \return Uniqueid of the associate channel.
- * \return \c NULL if \a control is \c NULL.
+ * \retval NULL if \a control is \c NULL.
  */
 const char *stasis_app_control_get_channel_id(
 	const struct stasis_app_control *control);
 
-/*!
- * \brief Dial an endpoint and bridge it to a channel in \c res_stasis
- *
- * If the channel is no longer in \c res_stasis, this function does nothing.
- *
- * \param control Control for \c res_stasis
- * \param endpoint The endpoint to dial.
- * \param exten Extension to dial if no endpoint specified.
- * \param context Context to use with extension.
- * \param timeout The amount of time to wait for answer, before giving up.
- *
- * \return 0 for success
- * \return -1 for error.
- */
-int stasis_app_control_dial(struct stasis_app_control *control, const char *endpoint, const char *exten,
-                            const char *context, int timeout);
-
 /*!
  * \brief Apply a bridge role to a channel controlled by a stasis app control
  *
@@ -500,6 +523,20 @@ void stasis_app_control_clear_roles(struct stasis_app_control *control);
  */
 int stasis_app_control_continue(struct stasis_app_control *control, const char *context, const char *extension, int priority);
 
+/*!
+ * \brief Exit \c res_stasis and move to another Stasis application.
+ *
+ * If the channel is no longer in \c res_stasis, this function does nothing.
+ *
+ * \param control Control for \c res_stasis
+ * \param app_name The name of the application to switch to
+ * \param app_args The list of arguments to pass to the application
+ *
+ * \return 0 for success
+ * \return -1 for error
+ */
+int stasis_app_control_move(struct stasis_app_control *control, const char *app_name, const char *app_args);
+
 /*!
  * \brief Redirect a channel in \c res_stasis to a particular endpoint
  *
@@ -531,6 +568,16 @@ int stasis_app_control_ring(struct stasis_app_control *control);
  */
 int stasis_app_control_ring_stop(struct stasis_app_control *control);
 
+/*!
+ * \brief Indicate progress to the channel associated with this control.
+ *
+ * \param control Control for \c res_stasis.
+ *
+ * \return 0 for success.
+ * \return -1 for error.
+ */
+int stasis_app_control_progress(struct stasis_app_control *control);
+
 /*!
  * \brief Send DTMF to the channel associated with this control.
  *
@@ -634,7 +681,7 @@ void stasis_app_control_silence_stop(struct stasis_app_control *control);
  * \param control Control for \c res_stasis.
  *
  * \return Most recent snapshot. ao2_cleanup() when done.
- * \return \c NULL if channel isn't in cache.
+ * \retval NULL if channel isn't in cache.
  */
 struct ast_channel_snapshot *stasis_app_control_get_snapshot(
 	const struct stasis_app_control *control);
@@ -675,10 +722,22 @@ int stasis_app_control_queue_control(struct stasis_app_control *control,
  * \param id Optional Unique ID to give to the bridge
  *
  * \return New bridge.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_bridge *stasis_app_bridge_create(const char *type, const char *name, const char *id);
 
+/*!
+ * \brief Create an invisible bridge of the specified type.
+ *
+ * \param type The type of bridge to be created
+ * \param name Optional name to give to the bridge
+ * \param id Optional Unique ID to give to the bridge
+ *
+ * \return New bridge.
+ * \retval NULL on error.
+ */
+struct ast_bridge *stasis_app_bridge_create_invisible(const char *type, const char *name, const char *id);
+
 /*!
  * \brief Returns the bridge with the given id.
  * \param bridge_id Uniqueid of the bridge.
@@ -727,6 +786,7 @@ struct ast_channel *stasis_app_bridge_playback_channel_find(
  *
  * \param bridge Bridge we are adding the playback channel for
  * \param chan Channel being added as a playback channel (must be ;1)
+ * \param control The app control structure for the playback channel
  *
  * \retval -1 failed to add channel for any reason
  * \retval 0 on success
@@ -735,6 +795,15 @@ int stasis_app_bridge_playback_channel_add(struct ast_bridge *bridge,
 	struct ast_channel *chan,
 	struct stasis_app_control *control);
 
+/*!
+ * \brief remove channel from list of ARI playback channels for bridges.
+ *
+ * \param bridge_id The unique ID of the bridge the playback channel is in.
+ * \param control The app control structure for the playback channel
+ */
+void stasis_app_bridge_playback_channel_remove(char *bridge_id,
+	struct stasis_app_control *control);
+
 /*!
  * \brief Result codes used when adding/removing channels to/from bridges.
  */
@@ -769,6 +838,48 @@ int stasis_app_control_add_channel_to_bridge(
 int stasis_app_control_remove_channel_from_bridge(
 	struct stasis_app_control *control, struct ast_bridge *bridge);
 
+/*!
+ * \brief Initialize bridge features into a channel control
+ *
+ * \note Bridge features on a control are destroyed after each bridge session,
+ *       so new features need to be initialized before each bridge add.
+ *
+ * \param control Control in which to store the features
+ *
+ * \return non-zero on failure
+ * \return zero on success
+ */
+int stasis_app_control_bridge_features_init(
+	struct stasis_app_control *control);
+
+/*!
+ * \brief Set whether DTMF from the channel is absorbed instead of passing through to the bridge
+ *
+ * \param control Control whose channel should have its DTMF absorbed when bridged
+ * \param absorb Whether DTMF should be absorbed (1) instead of passed through (0).
+ */
+void stasis_app_control_absorb_dtmf_in_bridge(
+	struct stasis_app_control *control, int absorb);
+
+/*!
+ * \brief Set whether audio from the channel is muted instead of passing through to the bridge
+ *
+ * \param control Control whose channel should have its audio muted when bridged
+ * \param mute Whether audio should be muted (1) instead of passed through (0).
+ */
+void stasis_app_control_mute_in_bridge(
+	struct stasis_app_control *control, int mute);
+
+/*!
+ * \since 18
+ * \brief Set whether COLP frames should be generated when joining the bridge
+ *
+ * \param control Control whose channel should have its COLP frames inhibited when bridged
+ * \param inhibit_colp Whether COLP frames should be generated (0) or not (1).
+ */
+void stasis_app_control_inhibit_colp_in_bridge(
+	struct stasis_app_control *control, int inhibit_colp);
+
 /*!
  * \since 12
  * \brief Gets the bridge currently associated with a control object.
@@ -780,7 +891,7 @@ int stasis_app_control_remove_channel_from_bridge(
  * \param control Control object for the channel to query.
  *
  * \return Associated \ref ast_bridge.
- * \return \c NULL if not associated with a bridge.
+ * \retval NULL if not associated with a bridge.
  */
 struct ast_bridge *stasis_app_get_bridge(struct stasis_app_control *control);
 
@@ -788,26 +899,9 @@ struct ast_bridge *stasis_app_get_bridge(struct stasis_app_control *control);
  * \brief Destroy the bridge.
  *
  * \param bridge_id Uniqueid of bridge to be destroyed
- *
- * \retval non-zero on failure
- * \retval zero on success
  */
 void stasis_app_bridge_destroy(const char *bridge_id);
 
-/*!
- * \brief Increment the res_stasis reference count.
- *
- * This ensures graceful shutdown happens in the proper order.
- */
-void stasis_app_ref(void);
-
-/*!
- * \brief Decrement the res_stasis reference count.
- *
- * This ensures graceful shutdown happens in the proper order.
- */
-void stasis_app_unref(void);
-
 /*!
  * \brief Get the Stasis message sanitizer for app_stasis applications
  *
@@ -818,7 +912,7 @@ struct stasis_message_sanitizer *stasis_app_get_sanitizer(void);
 /*!
  * \brief Indicate that this channel has had a StasisEnd published for it
  *
- * \param The channel that is exiting Stasis.
+ * \param chan The channel that is exiting Stasis.
  */
 void stasis_app_channel_set_stasis_end_published(struct ast_channel *chan);
 
@@ -862,6 +956,108 @@ int stasis_app_channel_unreal_set_internal(struct ast_channel *chan);
  */
 int stasis_app_channel_set_internal(struct ast_channel *chan);
 
+/*!
+ * \brief Dial a channel
+ * \param control Control for \c res_stasis.
+ * \param dialstring The dialstring to pass to the channel driver
+ * \param timeout Optional timeout in milliseconds
+ */
+int stasis_app_control_dial(struct stasis_app_control *control,
+		const char *dialstring, unsigned int timeout);
+
+/*!
+ * \brief Let Stasis app internals shut down
+ *
+ * This is called when res_stasis is unloaded. It ensures that
+ * the Stasis app internals can free any resources they may have
+ * allocated during the time that res_stasis was loaded.
+ */
+void stasis_app_control_shutdown(void);
+
+/*!
+ * \brief Enable/disable request/response and event logging on an application
+ *
+ * \param app The app to debug
+ * \param debug If non-zero, enable debugging. If zero, disable.
+ */
+void stasis_app_set_debug(struct stasis_app *app, int debug);
+
+/*!
+ * \brief Enable/disable request/response and event logging on an application
+ *
+ * \param app_name The app name to debug
+ * \param debug If non-zero, enable debugging. If zero, disable.
+ */
+void stasis_app_set_debug_by_name(const char *app_name, int debug);
+
+/*!
+ * \brief Get debug status of an application
+ *
+ * \param app The app to check
+ * \return The debug flag for the app || the global debug flag
+ */
+int stasis_app_get_debug(struct stasis_app *app);
+
+/*!
+ * \brief Get debug status of an application
+ *
+ * \param app_name The app_name to check
+ * \return The debug flag for the app || the global debug flag
+ */
+int stasis_app_get_debug_by_name(const char *app_name);
+
+/*!
+ * \brief Enable/disable request/response and event logging on all applications
+ *
+ * \param debug If non-zero, enable debugging. If zero, disable.
+ */
+void stasis_app_set_global_debug(int debug);
+
+struct ast_cli_args;
+
+/*!
+ * \brief Dump properties of a \c stasis_app to the CLI
+ *
+ * \param app The application
+ * \param a The CLI arguments
+ */
+void stasis_app_to_cli(const struct stasis_app *app, struct ast_cli_args *a);
+
+/*!
+ * \brief Convert and add the app's event type filter(s) to the given json object.
+ *
+ * \param app The application
+ * \param json The json object to add the filter data to
+ *
+ * \return The given json object
+ */
+struct ast_json *stasis_app_event_filter_to_json(struct stasis_app *app, struct ast_json *json);
+
+/*!
+ * \brief Set the application's event type filter
+ *
+ * \param app The application
+ * \param filter The allowed and/or disallowed event filter
+ *
+ * \return 0 if successfully set
+ */
+int stasis_app_event_filter_set(struct stasis_app *app, struct ast_json *filter);
+
+/*!
+ * \brief Check if the given event should be filtered.
+ *
+ * Attempts first to find the event in the application's disallowed events list.
+ * If found then the event won't be sent to the remote. If not found in the
+ * disallowed list then a search is done to see if it can be found in the allowed
+ * list. If found the event message is sent, otherwise it is not sent.
+ *
+ * \param app_name The application name
+ * \param event The event to check
+ *
+ * \return True if allowed, false otherwise
+ */
+int stasis_app_event_allowed(const char *app_name, struct ast_json *event);
+
 /*! @} */
 
 #endif /* _ASTERISK_STASIS_APP_H */
