@@ -41,6 +41,9 @@
 /*** DOCUMENTATION
 	<managerEvent language="en_US" name="AOC-S">
 		<managerEventInstance class="EVENT_FLAG_AOC">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when an Advice of Charge message is sent at the beginning of a call.</synopsis>
 			<syntax>
 				<channel_snapshot/>
@@ -77,7 +80,7 @@
 				<parameter name="Scale" />
 				<parameter name="Unit">
 					<enumlist>
-						<enum name="Octect" />
+						<enum name="Octet" />
 						<enum name="Segment" />
 						<enum name="Message" />
 					</enumlist>
@@ -92,6 +95,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="AOC-D">
 		<managerEventInstance class="EVENT_FLAG_AOC">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when an Advice of Charge message is sent during a call.</synopsis>
 			<syntax>
 				<channel_snapshot/>
@@ -150,6 +156,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="AOC-E">
 		<managerEventInstance class="EVENT_FLAG_AOC">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when an Advice of Charge message is sent at the end of a call.</synopsis>
 			<syntax>
 				<channel_snapshot/>
@@ -1389,8 +1398,6 @@ static char *aoc_cli_debug_enable(struct ast_cli_entry *e, int cmd, struct ast_c
  * \param name Name of the time structure to convert.
  * \param time Data to convert.
  * \param scale Data to convert.
- *
- * \return Nothing
  */
 static void aoc_time_str(struct ast_str **msg, const char *prefix, const char *name, unsigned long time, enum ast_aoc_time_scale scale)
 {
@@ -1407,9 +1414,7 @@ static void aoc_time_str(struct ast_str **msg, const char *prefix, const char *n
  * \param msg Event message string being built.
  * \param prefix Prefix to add to the amount lines.
  * \param amount Data to convert.
- * \param multipler to convert
- *
- * \return Nothing
+ * \param mult to convert
  */
 static void aoc_amount_str(struct ast_str **msg, const char *prefix, unsigned int amount, enum ast_aoc_currency_multiplier mult)
 {
@@ -1829,8 +1834,6 @@ static void aoc_event_blob_dtor(void *obj)
  * \param chan Channel associated with the AOC event. (May be NULL if no channel)
  * \param msg_type What kind of AOC event.
  * \param blob AOC data blob to publish.
- *
- * \return Nothing
  */
 static void aoc_publish_blob(struct ast_channel *chan, struct stasis_message_type *msg_type, struct ast_json *blob)
 {
