@@ -411,11 +411,17 @@ static int ast_set_indication_country(const char *country)
 {
 	struct ast_tone_zone *zone = NULL;
 
-	if (ast_strlen_zero(country) || !(zone = ast_get_indication_zone(country))) {
+	if (ast_strlen_zero(country)) {
+		ast_log(LOG_WARNING, "Failed to get indication zone, country not set\n");
 		return -1;
 	}
 
-	ast_verb(3, "Setting default indication country to '%s'\n", country);
+	if (!(zone = ast_get_indication_zone(country))) {
+		ast_log(LOG_WARNING, "Failed to get indication zone: %s\n", country);
+		return -1;
+	}
+
+	ast_log(LOG_NOTICE, "Setting default indication country to '%s'\n", country);
 
 	ao2_lock(ast_tone_zones);
 	if (default_tone_zone) {
@@ -533,7 +539,7 @@ static int ast_register_indication_country(struct ast_tone_zone *zone)
 
 	ao2_link(ast_tone_zones, zone);
 
-	ast_verb(3, "Registered indication country '%s'\n", zone->country);
+	ast_verb(5, "Registered indication country '%s'\n", zone->country);
 
 	return 0;
 }
@@ -588,7 +594,9 @@ static int ast_register_indication(struct ast_tone_zone *zone, const char *indic
 	}
 	AST_LIST_TRAVERSE_SAFE_END;
 
-	if (!(ts = ao2_alloc(sizeof(*ts), ast_tone_zone_sound_destructor))) {
+	ts = ao2_alloc_options(sizeof(*ts), ast_tone_zone_sound_destructor,
+		AO2_ALLOC_OPT_LOCK_NOLOCK);
+	if (!ts) {
 		return -1;
 	}
 
@@ -632,9 +640,7 @@ static struct ast_tone_zone *ast_tone_zone_alloc(void)
 
 static char *complete_country(struct ast_cli_args *a)
 {
-	char *res = NULL;
 	struct ao2_iterator i;
-	int which = 0;
 	size_t wordlen;
 	struct ast_tone_zone *tz;
 
@@ -642,17 +648,17 @@ static char *complete_country(struct ast_cli_args *a)
 
 	i = ao2_iterator_init(ast_tone_zones, 0);
 	while ((tz = ao2_iterator_next(&i))) {
-		if (!strncasecmp(a->word, tz->country, wordlen) && ++which > a->n) {
-			res = ast_strdup(tz->country);
-		}
-		tz = ast_tone_zone_unref(tz);
-		if (res) {
-			break;
+		if (!strncasecmp(a->word, tz->country, wordlen)) {
+			if (ast_cli_completion_add(ast_strdup(tz->country))) {
+				ast_tone_zone_unref(tz);
+				break;
+			}
 		}
+		ast_tone_zone_unref(tz);
 	}
 	ao2_iterator_destroy(&i);
 
-	return res;
+	return NULL;
 }
 
 static char *handle_cli_indication_add(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
@@ -702,7 +708,11 @@ static char *handle_cli_indication_add(struct ast_cli_entry *e, int cmd, struct
 	ast_tone_zone_lock(tz);
 
 	if (ast_register_indication(tz, a->argv[3], a->argv[4])) {
-		ast_log(LOG_WARNING, "Unable to register indication %s/%s\n", a->argv[2], a->argv[3]);
+		if (ast_strlen_zero(a->argv[3])) {
+			ast_log(LOG_WARNING, "Unable to register indication %s\n", a->argv[2]);
+		} else {
+			ast_log(LOG_WARNING, "Unable to register indication %s/%s\n", a->argv[2], a->argv[3]);
+		}
 		if (created_country) {
 			ast_unregister_indication_country(a->argv[2]);
 		}
@@ -718,17 +728,17 @@ static char *handle_cli_indication_add(struct ast_cli_entry *e, int cmd, struct
 
 static char *complete_indications(struct ast_cli_args *a)
 {
-	char *res = NULL;
-	int which = 0;
 	size_t wordlen;
 	struct ast_tone_zone_sound *ts;
-	struct ast_tone_zone *tz, tmp_tz = {
+	struct ast_tone_zone *tz;
+	struct ast_tone_zone tmp_tz = {
 		.nrringcadence = 0,
 	};
 
 	ast_copy_string(tmp_tz.country, a->argv[a->pos - 1], sizeof(tmp_tz.country));
 
-	if (!(tz = ao2_find(ast_tone_zones, &tmp_tz, OBJ_POINTER))) {
+	tz = ao2_find(ast_tone_zones, &tmp_tz, OBJ_POINTER);
+	if (!tz) {
 		return NULL;
 	}
 
@@ -736,16 +746,17 @@ static char *complete_indications(struct ast_cli_args *a)
 
 	ast_tone_zone_lock(tz);
 	AST_LIST_TRAVERSE(&tz->tones, ts, entry) {
-		if (!strncasecmp(a->word, ts->name, wordlen) && ++which > a->n) {
-			res = ast_strdup(ts->name);
-			break;
+		if (!strncasecmp(a->word, ts->name, wordlen)) {
+			if (ast_cli_completion_add(ast_strdup(ts->name))) {
+				break;
+			}
 		}
 	}
 	ast_tone_zone_unlock(tz);
 
 	tz = ast_tone_zone_unref(tz);
 
-	return res;
+	return NULL;
 }
 
 static char *handle_cli_indication_remove(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
@@ -763,9 +774,11 @@ static char *handle_cli_indication_remove(struct ast_cli_entry *e, int cmd, stru
 	case CLI_GENERATE:
 		if (a->pos == 2) {
 			return complete_country(a);
-		} else if (a->pos == 3) {
+		}
+		if (a->pos == 3) {
 			return complete_indications(a);
 		}
+		return NULL;
 	}
 
 	if (a->argc != 3 && a->argc != 4) {
@@ -829,6 +842,15 @@ static char *handle_cli_indication_show(struct ast_cli_entry *e, int cmd, struct
 			tz = ast_tone_zone_unref(tz);
 		}
 		ao2_iterator_destroy(&iter);
+
+		ao2_lock(ast_tone_zones);
+		if (default_tone_zone) {
+			ast_cli(a->fd, "===========================\n");
+			tz = ast_tone_zone_ref(default_tone_zone);
+			ast_cli(a->fd, "Default tone zone: %s\n", tz->country);
+			ast_tone_zone_unref(tz);
+		}
+		ao2_unlock(ast_tone_zones);
 		return CLI_SUCCESS;
 	}
 
@@ -901,11 +923,11 @@ static void store_tone_zone_ring_cadence(struct ast_tone_zone *zone, const char
 	ast_copy_string(buf, val, sizeof(buf));
 
 	while ((ring = strsep(&c, ","))) {
-		int *tmp, val;
+		int *tmp, value;
 
 		ring = ast_strip(ring);
 
-		if (!isdigit(ring[0]) || (val = atoi(ring)) == -1) {
+		if (!isdigit(ring[0]) || (value = atoi(ring)) == -1) {
 			ast_log(LOG_WARNING, "Invalid ringcadence given '%s'.\n", ring);
 			continue;
 		}
@@ -915,7 +937,7 @@ static void store_tone_zone_ring_cadence(struct ast_tone_zone *zone, const char
 		}
 
 		zone->ringcadence = tmp;
-		tmp[zone->nrringcadence] = val;
+		tmp[zone->nrringcadence] = value;
 		zone->nrringcadence++;
 	}
 }
@@ -1074,8 +1096,13 @@ static int load_indications(int reload)
 
 	/* determine which country is the default */
 	country = ast_variable_retrieve(cfg, "general", "country");
-	if (ast_strlen_zero(country) || ast_set_indication_country(country)) {
-		ast_log(LOG_WARNING, "Unable to set the default country (for indication tones)\n");
+	if (!ast_strlen_zero(country)) {
+		ast_log(LOG_NOTICE, "Default country for indication tones: %s\n", country);
+		if (ast_set_indication_country(country)) {
+			ast_log(LOG_WARNING, "Unable to set the default country (for indication tones)\n");
+		}
+	} else {
+		ast_log(LOG_WARNING, "Missing default country (for indication tones)\n");
 	}
 
 	res = 0;
@@ -1114,7 +1141,7 @@ static int ast_tone_zone_cmp(void *obj, void *arg, int flags)
  * \internal
  * \brief Clean up resources on Asterisk shutdown
  */
-static void indications_shutdown(void)
+static int unload_module(void)
 {
 	ast_cli_unregister_multiple(cli_indications, ARRAY_LEN(cli_indications));
 	if (default_tone_zone) {
@@ -1125,29 +1152,39 @@ static void indications_shutdown(void)
 		ao2_ref(ast_tone_zones, -1);
 		ast_tone_zones = NULL;
 	}
+
+	return 0;
 }
 
 /*! \brief Load indications module */
-int ast_indications_init(void)
+static int load_module(void)
 {
-	if (!(ast_tone_zones = ao2_container_alloc(NUM_TONE_ZONE_BUCKETS,
-			ast_tone_zone_hash, ast_tone_zone_cmp))) {
-		return -1;
+	ast_tone_zones = ao2_container_alloc_hash(AO2_ALLOC_OPT_LOCK_MUTEX, 0,
+		NUM_TONE_ZONE_BUCKETS, ast_tone_zone_hash, NULL, ast_tone_zone_cmp);
+	if (!ast_tone_zones) {
+		return AST_MODULE_LOAD_FAILURE;
 	}
 
 	if (load_indications(0)) {
-		indications_shutdown();
-		return -1;
+		return AST_MODULE_LOAD_FAILURE;
 	}
 
 	ast_cli_register_multiple(cli_indications, ARRAY_LEN(cli_indications));
 
-	ast_register_cleanup(indications_shutdown);
-	return 0;
+	return AST_MODULE_LOAD_SUCCESS;
 }
 
 /*! \brief Reload indications module */
-int ast_indications_reload(void)
+static int reload_module(void)
 {
 	return load_indications(1);
 }
+
+AST_MODULE_INFO(ASTERISK_GPL_KEY, AST_MODFLAG_GLOBAL_SYMBOLS | AST_MODFLAG_LOAD_ORDER, "Indication Tone Handling",
+	.support_level = AST_MODULE_SUPPORT_CORE,
+	.load = load_module,
+	.unload = unload_module,
+	.reload = reload_module,
+	.load_pri = AST_MODPRI_CORE,
+	.requires = "extconfig",
+);
