@@ -31,8 +31,6 @@
 
 #include "asterisk.h"
 
-ASTERISK_REGISTER_FILE()
-
 #include "asterisk/test.h"
 #include "asterisk/module.h"
 #include "asterisk/sorcery.h"
@@ -63,7 +61,7 @@ struct sorcery_memory_cache_thrash_thread {
 	unsigned int average_execution_time;
 };
 
-/*! \brief Structure for memory cache thrasing */
+/*! \brief Structure for memory cache thrashing */
 struct sorcery_memory_cache_thrash {
 	/*! \brief The sorcery instance being tested */
 	struct ast_sorcery *sorcery;
@@ -162,7 +160,7 @@ static void sorcery_memory_cache_thrash_destroy(void *obj)
 
 /*!
  * \internal
- * \brief Set up thrasing against a memory cache on a sorcery instance
+ * \brief Set up thrashing against a memory cache on a sorcery instance
  *
  * \param cache_configuration The sorcery memory cache configuration to use
  * \param update_threads The number of threads which should be constantly updating sorcery
@@ -220,7 +218,11 @@ static struct sorcery_memory_cache_thrash *sorcery_memory_cache_thrash_create(co
 		/* This purposely holds no ref as the main thrash structure does */
 		thread->sorcery = thrash->sorcery;
 
-		AST_VECTOR_APPEND(&thrash->threads, thread);
+		if (AST_VECTOR_APPEND(&thrash->threads, thread)) {
+			ast_free(thread);
+			ao2_ref(thrash, -1);
+			return NULL;
+		}
 	}
 
 	return thrash;
